pub type DomRoot<T> = Root<Dom<T>>;Expand description
A rooted reference to a DOM object.
Aliased Type
pub struct DomRoot<T> {
value: Dom<T>,
root_list: *const RootCollection,
}Fields
value: Dom<T>The value to root.
root_list: *const RootCollectionList that ensures correct dynamic root ordering
Implementations
Sourceimpl<T: Castable> DomRoot<T>
impl<T: Castable> DomRoot<T>
Sourceimpl<T: DomObject> DomRoot<T>
impl<T: DomObject> DomRoot<T>
Sourcepub fn as_traced(&self) -> Dom<T>
pub fn as_traced(&self) -> Dom<T>
Create a traced version of this rooted object.
Safety
This should never be used to create on-stack values. Instead these values should always end up as members of other DOM objects.
Sourcepub fn as_unrooted<'no_gc>(&self, no_gc: &'no_gc NoGC) -> UnrootedDom<'no_gc, T>
pub fn as_unrooted<'no_gc>(&self, no_gc: &'no_gc NoGC) -> UnrootedDom<'no_gc, T>
Return an unrooted version of this DOM object (UnrootedDom<T>) suitable for use on the
stack which has the lifetime of the provided NoGC token.