pub fn rooted_heap_handle<'a, T: DomObject, U: GCMethods + Copy>(
object: &'a T,
f: impl Fn(&'a T) -> &'a Heap<U>,
) -> Handle<'a, U>Expand description
Returns a handle to a Heap member of a reflected DOM object. The provided callback acts as a projection of the rooted-ness of the provided DOM object; it must return a reference to a Heap member of the DOM object.